/****************************************************************************************************************
   Program: 010_import_taxonomy_xwalk.sas

   Purpose: Read an Excel worksheet into SAS that contains taxonomy codes and variables describing specialty and 
   licensure type (MD/DO, NP, or PA)

   Input files: NDWS_taxonomy by dementia_W1.xlsx

   Output files: _010_taxonomy_xwalk.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname out "<output directory>";

/* Current taxonomies to include input file */
%let xwalk = <input directory>/NDWS_taxonomy by dementia_W1.xlsx;

/* Output file */
%let outfile = out._010_taxonomy_xwalk;

proc format;
	value lics
		0 = "MD/DO"
		1 = "NP"
		2 = "PA"
	;
run;

/*********************************************************************************************************
Read in Taxonomy Crosswalk
*********************************************************************************************************/
proc import datafile = "&xwalk." out = xwalk dbms = xlsx replace;
	getnames = no;
	datarow = 2;
	sheet = "taxonomy-xwalk";
run;

data &outfile.;
	set xwalk;
	format C lics.;
	rename A = prvdr_txnmy_desc
           B = spclty_updt_ndws
		   C = licensing
		   D = prvdr_txnmy_cd
	;
	label  A = "Provider Taxonomy Description"
           B = "Specialty (DM Update for NDWS)"
		   C = "Licensing (MD/DO = 0, NP = 1, PA = 2, Other = Missing)"
		   D = "Provider Taxonomy Code"
	;
	if missing(cats(of _all_)) then delete;

	keep A B C D;
run;