/****************************************************************************************************************
   Program: 103_dementia_benes.sas

   Purpose: Identify nursing home residents with dementia in MDS data

   Input files: ASSMNT.MDS_ASMT3_2021

   Output files: _103_mds_dmnt_bene_lvl_2021.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname out "<output directory>";

%let yr = 2021;
%let indata = assmnt.mds_asmt3_&yr.;
%let outdata = out._103_mds_dmnt_bene_lvl_&yr.;

/* Read in MDS data and flag records with dementia and limit to 2021 assessments */
data mds_&yr.;
	set &indata.;
	dement = (i4200_alzhmr_cd = "1" or i4800_dmnt_cd = "1");
	if year(trgt_dt) = &yr.;
run;

/* Rollup dementia flag to the beneficiary level */
proc sql;
	create table &outdata. as
	select bene_id,
		   max(dement) as mds_dement,
		   1 as mds
	from mds_&yr.
	group by bene_id;
quit;