/****************************************************************************************************************
   Program: 105_ffs_ma_mds_dementia_benes.sas

   Purpose: Create final bene-level dementia dataset with FFS, MA Encounter, and 
            MDS bene-level dementia data

   Input files: ndws_cc_bene_ff_ffs_by.sas7bdat
				_102_final_dmnt_bene_lvl_2021.sas7bdat
				_103_mds_dmnt_bene_lvl_2021.sas7bdat

   Output files: _105_final_dmnt_bene_lvl_2021.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname ffs_in "<ffs input directory>";
libname ma_in "<ma input directory>";
libname mds_in "<mds input directory>";
libname out "<output directory>";

%let yr = 2021;
%let indataffs = ffs_in.ndws_cc_bene_ff_ffs_by;
%let indatama = ma_in._102_final_dmnt_bene_lvl_&yr.;
%let indatamds = mds_in._103_mds_dmnt_bene_lvl_&yr.;
%let outdata = out._105_final_dmnt_bene_lvl_&yr.;

/* Merge FFS, MA Encounter, and MDS bene-level dementia files */
data ffs_ma_mds_&yr.;
   merge &indataffs. (in = a)
         &indatama.  (in = b)
         &indatamds. (in = c);
   by bene_id;
   bene_in_ffs = a;
   bene_in_ma = b;
   bene_in_mds = c;
   rename inp_n_dmnt_clms = ffs_inp_n_dmnt_clms
          snf_n_dmnt_clms = ffs_snf_n_dmnt_clms
          hha_n_dmnt_clms = ffs_hha_n_dmnt_clms
          hsp_n_dmnt_clms = ffs_hsp_n_dmnt_clms
          crrop_n_dmnt_clms = ffs_crrop_n_dmnt_clms;
run;

/* Update MDS flag */
data ffs_ma_mds2_&yr.;
   set ffs_ma_mds_&yr.;
   if mds_dement = 0 and mds = 1 then mds = 0;
   if mds_dement = 1 and mds = 1 then mds = 1;
run;

/* Drop benes with no dementia */
data &outdata.;
   set ffs_ma_mds2_&yr.;
   if ffs_clm = . and ma_enctr = . and (mds_dement = 0 or mds_dement = .) then delete;
run;