/****************************************************************************************************************
   Program: 110_add_mbsf_info_baseyr.sas

   Purpose: Add MBSF info to finder file of beneficiaries with dementia for CY 2021

   Input files: _105_final_dmnt_bene_lvl_2021.sas7bdat
                MBSF.MBSF_ABCD_2021

   Output files: ndws_cc_bene_ff_mbsf_by.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname in "<input directory>" access=readonly;
libname out "<output directory>";

%let base_yr = 2021;

%let infile = in._105_final_dmnt_bene_lvl_2021;
%let outfile = out.ndws_cc_bene_ff_mbsf_by;

%let keepvar_ff = bene_id ffs_clm hspc ma_enctr mds;
%let keepvar_abcd = bene_id bene_death_dt rti_race_cd cst_shr_grp_cd_01-cst_shr_grp_cd_12
                    bene_hmo_cvrage_tot_mons bene_hi_cvrage_tot_mons bene_smi_cvrage_tot_mons
                    dual_stus_cd_01-dual_stus_cd_12;

data &outfile.(keep=bene_id ffs_clm hspc ma_enctr mds rti_race_cd any_lis always_unk_lis
                    dual dual_or_lis black hispanic white alloths);
   merge &infile.(in=a keep=&keepvar_ff.)
         MBSF.MBSF_ABCD_&base_yr.(in=b keep=&keepvar_abcd.);
   by bene_id;
   if a;

   no_mbsf = not b;

   any_lis = 0;
   always_unk_lis = 1;

   array csg_flgs cst_shr_grp_cd_01-cst_shr_grp_cd_12;

   do over csg_flgs;
      if not (csg_flgs in ("00","13") or missing(csg_flgs)) then do;
         always_unk_lis = 0;
         if "01" <= csg_flgs <= "08" then do;
            any_lis = 1;
            leave;
         end;
      end;
   end;

   dual = 0;

   array dual_flgs dual_stus_cd_01-dual_stus_cd_12;

   do over dual_flgs;
      if dual_flgs in ("01","02","03","04","05","06","08") then do;
         dual = 1;
         leave;
      end;
   end;

   dual_or_lis = (dual or any_lis);

   bene_deceased = (. < bene_death_dt < mdy(1,1,&base_yr.));

   black = (rti_race_cd = "2");
   hispanic = (rti_race_cd = "5");
   white = (rti_race_cd = "1");
   alloths = (rti_race_cd in ("0","3","4","6"));

   if missing(ffs_clm) then do;
      if bene_hmo_cvrage_tot_mons = 12 or
         (bene_hmo_cvrage_tot_mons = bene_hi_cvrage_tot_mons and
          bene_hmo_cvrage_tot_mons = bene_smi_cvrage_tot_mons) then ffs_clm = .;
      else if bene_hmo_cvrage_tot_mons <= max(bene_hi_cvrage_tot_mons,bene_smi_cvrage_tot_mons) and
              (bene_hi_cvrage_tot_mons > 0 or bene_smi_cvrage_tot_mons > 0) then ffs_clm = 0;
   end;

   if missing(ma_enctr) then do;
      if bene_hmo_cvrage_tot_mons = 0 then ma_enctr = .;
      else if bene_hmo_cvrage_tot_mons > 0 then ma_enctr = 0;
   end;

   if not (no_mbsf or bene_deceased) then output;

run;