/****************************************************************************************************************
   Program: 120_add_mbsf_info_recentyr.sas

   Purpose: Add MBSF info to finder file of beneficiaries with dementia for FY 2023

   Input files: ndws_cc_bene_ff_ffs_ry.sas7bdat
                MBSF.MBSF_ABCD_2022
                MBSF.MBSF_ABCD_2023

   Output files: ndws_cc_bene_ff_mbsf_ffs_ry.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname in "<input directory>" access=readonly;
libname out "<output directory>";

%let infile = in.ndws_cc_bene_ff_ffs_ry;
%let outfile = out.ndws_cc_bene_ff_mbsf_ffs_ry;

%let yr1 = 2023;
%let yr2 = 2022;

%let keepvar_ff = bene_id ffs_clm hspc;
%let keepvar_abcd_yr1 = bene_id bene_death_dt rti_race_cd
                        cst_shr_grp_cd_01-cst_shr_grp_cd_09 dual_stus_cd_01-dual_stus_cd_09;
%let keepvar_abcd_yr2 = bene_id bene_death_dt rti_race_cd
                        cst_shr_grp_cd_10-cst_shr_grp_cd_12 dual_stus_cd_10-dual_stus_cd_12;

data &outfile.(keep=bene_id ffs_clm hspc rti_race_cd any_lis always_unk_lis
                    dual dual_or_lis black hispanic white alloths);
   merge &infile.(in=a keep=&keepvar_ff.)
         MBSF.MBSF_ABCD_&yr1.(in=b keep=&keepvar_abcd_yr1. rename=(rti_race_cd = rti_race_cd_&yr1.
                                                                   bene_death_dt = bene_death_dt_&yr1.))
         MBSF.MBSF_ABCD_&yr2.(in=c keep=&keepvar_abcd_yr2. rename=(rti_race_cd = rti_race_cd_&yr2.
                                                                   bene_death_dt = bene_death_dt_&yr2.));
   by bene_id;
   if a;

   length rti_race_cd $ 1;

   no_mbsf_&yr1. = not b;
   no_mbsf_&yr2. = not c;
   no_mbsf = no_mbsf_&yr1. and no_mbsf_&yr2.;

   any_lis = 0;
   always_unk_lis = 1;

   array csg_flgs cst_shr_grp_cd_01-cst_shr_grp_cd_12;

   do over csg_flgs;
      if not (csg_flgs in ("00","13") or missing(csg_flgs)) then do;
         always_unk_lis = 0;
         if "01" <= csg_flgs <= "08" then do;
            any_lis = 1;
            leave;
         end;
      end;
   end;

   dual = 0;

   array dual_flgs dual_stus_cd_01-dual_stus_cd_12;

   do over dual_flgs;
      if dual_flgs in ("01","02","03","04","05","06","08") then do;
         dual = 1;
         leave;
      end;
   end;

   dual_or_lis = (dual or any_lis);

   if missing(bene_death_dt_&yr1.) then bene_death_dt = bene_death_dt_&yr2.;
   else bene_death_dt = bene_death_dt_&yr1.;

   bene_deceased = (. < bene_death_dt < mdy(10,1,&yr2.));

   if missing(rti_race_cd_&yr1.) then rti_race_cd = rti_race_cd_&yr2.;
   else rti_race_cd = rti_race_cd_&yr1.;

   black = (rti_race_cd = "2");
   hispanic = (rti_race_cd = "5");
   white = (rti_race_cd = "1");
   alloths = (rti_race_cd in ("0","3","4","6"));

   if not (no_mbsf or bene_deceased) then output;

run;