/****************************************************************************************************************
   Program: 600_preprocess_iqvia.sas

   Purpose: This program reads in the two IQVIA datasets for the potential sample frame clinicians, combines the 
			two datasets, and saves for geocoding in the next step.
	
   Input files: OM404171_500_ma_only_by_ffs_ry_npis_Final_hcp_addr.csv
				OM404171_500_ma_only_by_ffs_ry_npis_Final_hcp_affil.csv

   Output files: _600_iqvia_preprocessed.sas7bdat
				 _600_iqvia_preprocessed.csv
****************************************************************************************************************/
options nocenter mprint obs=max;
options validvarname=v7;

%let in_path = <input directory>;
%let infile_addr = &in_path.\OM404171_500_ma_only_by_ffs_ry_npis_Final_hcp_addr.csv;
%let infile_affil = &in_path.\OM404171_500_ma_only_by_ffs_ry_npis_Final_hcp_affil.csv;

%let out_path = <output directory>;
libname out "&out_path.";
%let outfile_csv = &out_path.\_600_iqvia_preprocessed.csv;
%let outfile_sas = out._600_iqvia_preprocessed;

/* Import the IQVIA datasets */
proc import datafile = "&infile_addr." out = hcp_addr dbms = csv replace;
	guessingrows = max;
run;
proc import datafile = "&infile_affil." out = hcp_affil dbms = csv replace;
	guessingrows = max;
run;

/* Limit to relevant rows in each file and append the two files */
data hcp_addr;
	length addr_ln_1_txt $80.
		   addr_ln_2_txt $80. 
		   city_nm $50. 
		   st_cd $2.
		   fips_st_cd $2.
		   zip5_cd $5.
		   zip4_cd $4.
	;
	set hcp_addr;
	if not missing(hcp_hce_id);
run;
data hcp_affil;
	length addr_ln_1_txt $80.
		   addr_ln_2_txt $80. 
		   city_nm $50. 
		   st_cd $2.
		   fips_st_cd $2.
		   zip5_cd $5.
		   zip4_cd $4.
	;
	set hcp_affil;
	if not missing(hcp_hce_id);
run;
data iqvia_all;
	set hcp_affil hcp_addr;
	keep clt_npi npi addr_ln_1_txt addr_ln_2_txt city_nm st_cd fips_st_cd zip5_cd zip4_cd geo_addr_lat_nbr geo_addr_lon_nbr;
run;

/* Save dataset with only variables needed to find the rural_flag; export to CSV for geocoding */
data &outfile_sas.;
	set iqvia_all;
	drop clt_npi;
run;
proc export data = &outfile_sas. outfile = "&outfile_csv." dbms = csv replace;
run;

/* Clean environment */
proc datasets lib = work kill nolist;
run;