/****************************************************************************************************************
   Program: 610_npi_geocoded_diagnostics.sas

   Purpose: This program takes the geocoded data from the manual ArcGIS processing and merges it with the data 
			from before geocoding to determine which NPIs were geocoded and which were not.
			
   Input files: _600_iqvia_preprocessed.sas7bdat
				_600_iqvia_preprocessed_geocoded.csv

   Output files: _610_npi_geocoded.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;
options validvarname=v7;

%let in_path = <output directory>;
libname in "&in_path." access = readonly;
%let infile_pregeocoded = in._600_iqvia_preprocessed;
%let infile_geocoded = &in_path.\_600_iqvia_preprocessed_geocoded.csv;

libname out "<output directory>";
%let outfile = out._610_npi_geocoded;

/* Read in geocoded file */
proc import datafile = "&infile_geocoded." out = npi_geocoded dbms = csv replace;
	guessingrows = 5000; /* can use 5,000 here because the variables we need will not be truncated */
run;
data npi_geocoded;
	set npi_geocoded;
	if status = "U" then do; /* if unmatched then set long / lat to missing */
		x = .;
		y = .;
	end;
	keep user_npi addr_type status match_type score x y;
run;
proc sort data = npi_geocoded;
	by user_npi;
run;

/* See which NPIs did not go through the geocoding process */
data npi_orig;
	set &infile_pregeocoded.;
	user_npi = input(npi, 12.);
	drop npi;
run;
proc sort data = npi_orig;
	by user_npi;
run;

data &outfile.;
	merge npi_orig (in = a) npi_geocoded (in = b);
	by user_npi;
	length npi_was_geocoded $10.;
	if a and b then npi_was_geocoded = "Yes";
	if a and not b then npi_was_geocoded = "No";
	if not a and b then npi_was_geocoded = "Error";
	rename user_npi = npi;
run;

/* Clean environment */
proc datasets lib = work kill nolist;
run;
