/****************************************************************************************************************
   Program: 630_create_npi_rural.sas

   Purpose: This program maps the census tract to a RUCA code which is then used to create a 0/1 binary
			rural flag.

   Input files: _620_npi_tracts.sas7bdat
				ruca_xwalk.sas7bdat

   Output files: _630_npi_rural.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;
options validvarname=v7;

/* Setup environment */
libname ruca_in "<input directory>" access = readonly;
libname npi_in "<output directory>" access = readonly;
libname out "<output directory>";
%let in_npi = npi_in._620_npi_tracts;
%let in_ruca = ruca_in.ruca_xwalk;
%let outfile = out._630_npi_rural;

/* Read in RUCA data */
data ruca_xwalk;
   set &in_ruca. (keep = tract_fips_cd primary_ruca_cd);
   if 1 <= primary_ruca_cd <= 6 then rural = 0;
   else if 7 <= primary_ruca_cd <= 10 then rural = 1;
   else rural = .;
run;

/* Read in NPI data */
data npi_tract;
   set &in_npi. (rename = (geoid = tract_fips_cd));
run;
proc sort data = npi_tract;
   by tract_fips_cd;
run;

/* Merge NPI data with RUCA data by Census tract */
data npi_tract_ruca;
   merge npi_tract (in=a) ruca_xwalk (in=b);
   by tract_fips_cd;
   if a;
run;
proc sort data = npi_tract_ruca out = &outfile. (drop = on_border);
	by npi;
run;

/* Clean up environment */
proc datasets lib = work kill nolist;
run; quit;
