/****************************************************************************************************************
   Program: 		640_geocoded_diagnostics.sas

   Purpose: 		This program runs diagnostics on the geocoded addresses from the NPPES (we use NPPES addresses
					for NPIs who were not found in IQVIA data or whose IQVIA addresses did not geocode in the 
					prior programs) 

   Input files: 	_020_npi.csv
					_020_npi_geocoded.csv

   Output files: 	_640_npi_geocoded.sas7bdat
****************************************************************************************************************/
/* Setup environment */
options nocenter mprint validvarname = v7 obs = max;

%let inpath = <input directory>;
libname out "<output directory>";
%let outfile = out._640_npi_geocoded;

/* Read in the original NPI address file and the geocoded address file */
proc import datafile = "&inpath.\_020_npi.csv" out = npi_orig dbms = csv replace;
	guessingrows = max;
run;
proc import datafile = "&inpath.\_020_npi_geocoded.csv" out = npi_geocoded dbms = csv replace;
	guessingrows = 5000;
run;
data npi_geocoded;
	set npi_geocoded;
	keep user_npi status match_type score x y;
	rename user_npi = npi;
	if status = "U" then do; /* if unmatched then set long / lat to missing */
		x = .;
		y = .;
	end;
run;

/* See which NPIs did not get geocoded */
proc sort data = npi_orig;
	by npi;
run;
proc sort data = npi_geocoded;
	by npi;
run;
data &outfile.;
	merge npi_orig (in = a keep = npi priority_:) npi_geocoded (in = b);
	by npi;
	length npi_was_geocoded $10.;
	if a and b then npi_was_geocoded = "Yes";
	if a and not b then npi_was_geocoded = "No";
	if not a and b then npi_was_geocoded = "Error";
run;

/* Clean up environment */
proc datasets lib = work kill nolist;
run; quit;