/****************************************************************************************************************
   Program: 		660_create_npi_rural.sas

   Purpose: 		Merge NPIs' NPPES addresses to RUCA code data by census tract.

   Input files: 	ruca_xwalk.sas7bdat
                	_650_npi_tracts.sas7bdat

   Output files: 	_660_npi_rural.sas7bdat
****************************************************************************************************************/
/* Setup environment */
options nocenter mprint validvarname = v7 obs = max;

%let inpath = <input directory>;
%let outpath = <output directory>;
libname in1 "&inpath." access=readonly;
libname in2 "&outpath." access=readonly;
libname out "&outpath.";
%let in_ruca = in1.ruca_xwalk;
%let in_npi = in2._650_npi_tracts;
%let outfile = out._660_npi_rural;

/* Read in RUCA data */
data ruca_xwalk;
   set &in_ruca. (keep = tract_fips_cd primary_ruca_cd);
   if 1 <= primary_ruca_cd <= 6 then rural = 0;
   else if 7 <= primary_ruca_cd <= 10 then rural = 1;
   else rural = .;
run;

/* Read in NPI data */
data npi_tract;
   set &in_npi. (rename = (geoid = tract_fips_cd));
run;
proc sort data = npi_tract;
   by tract_fips_cd;
run;

/* Merge NPI data with RUCA data by Census tract */
data npi_tract_ruca;
   merge npi_tract (in=a) ruca_xwalk (in=b);
   by tract_fips_cd;
   if a;
   in_npi = a;
   in_ruca_xwalk = b;
   in_npi_missing_tract = (a and missing(tract_fips_cd));
run;
proc sort data = npi_tract_ruca out = &outfile. (drop = on_border in:);
	by npi;
run;

/* Clean up environment */
proc datasets lib = work kill nolist;
run; quit;